<?php
//##copyright##

$iaComment = $iaCore->factoryPlugin('comments', iaCore::FRONT, 'comment');

if (iaView::REQUEST_JSON == $iaView->getRequestType() && isset($_POST['action']))
{
	$error = false;
	$messages = array();
	$output = array();

	if (iaCore::ACTION_ADD == $_POST['action'])
	{
		iaCore::util();

		$items = explode(',', $iaCore->get('comments_items_enabled'));
		$min_chars = $iaCore->get('comment_min_chars');
		$max_chars = $iaCore->get('comment_max_chars');
		$comment = array(
			'author' => iaUtil::checkPostParam('author'),
			'item' => iaUtil::checkPostParam('item'),
			'item_id' => (int)iaUtil::checkPostParam('item_id'),
			'email' => iaUtil::checkPostParam('email'),
			'url' => iaUtil::checkPostParam('url'),
			'body' => iaUtil::checkPostParam('body'),
			'member_id' => (int)iaUsers::getIdentity()->id,
			'ip' => $iaCore->util()->getIp(),
			'status' => $iaCore->get('comments_approval') ? iaCore::STATUS_ACTIVE : iaCore::STATUS_INACTIVE,
		);

		$iaUtil = iaCore::util();
		if (!defined('IA_NOUTF'))
		{
			iaUtf8::loadUTF8Core();
			iaUtf8::loadUTF8Util('ascii', 'validation', 'bad', 'utf8_to_ascii');
		}

		// CHECK: item
		if (!in_array($comment['item'], $items))
		{
			$error = true;
			$messages[] = iaLanguage::get('error_item_not_allowed');
		}

		if (!iaUsers::hasIdentity())
		{
			// CHECK: author
			if (empty($comment['author']))
			{
				$error = true;
				$messages[] = iaLanguage::get('error_comment_author');
			}
			else
			{
				$comment['author'] = iaSanitize::html(utf8_bad_replace($comment['author']));
			}

			// CHECK: email
			if (!iaValidate::isEmail($comment['email']))
			{
				$error = true;
				$messages[] = iaLanguage::get('error_comment_email');
			}

			// CHECK: url
			if (!iaValidate::isUrl($comment['url']))
			{
				$error = true;
				$messages[] = iaLanguage::get('error_url');
			}
		}

		// CHECK: body
		if (!utf8_is_valid($comment['body']))
		{
			$comment['body'] = utf8_bad_replace($comment['body']);
		}

		if ($iaCore->get('comments_allow_wysiwyg'))
		{
			$comment['body'] = $iaUtil->safeHTML($comment['body']);
		}
		else
		{
			$comment['body'] = nl2br(iaSanitize::html($comment['body']));
		}

		$len = utf8_is_ascii($comment['body']) ? strlen($comment['body']) : utf8_strlen($comment['body']);

		if (empty($comment['body']))
		{
			$error = true;
			$messages[] = iaLanguage::get('error_comment');
		}
		elseif ($min_chars > 0 && $len < $min_chars)
		{
			$error = true;
			$messages[] = iaLanguage::getf('error_min_comment', array('length' => $min_chars));
		}
		elseif ($max_chars > 0 && $len > $max_chars)
		{
			$error = true;
			$messages[] = iaLanguage::getf('error_max_comment', array('length' => $max_chars));
		}

		// CHECK: captcha
		if (!iaValidate::isCaptchaValid())
		{
			$error = true;
			$messages[] = iaLanguage::get('confirmation_code_incorrect');
		}

		if (!$error)
		{
			$iaDb->setTable('comments');
			$id = $iaDb->insert($comment, array('date' => iaDb::FUNCTION_NOW));

			if ($iaCore->get('comments_approval'))
			{
				$iaSmarty = $iaCore->factory('smarty');

				$output['date'] = strftime($iaCore->get('date_format'), time());

				$iaSmarty->assign('comment', $iaComment->getById($id));
				$iaSmarty->assign('img', IA_TPL_URL . 'img/');

				$output['html'] = $iaSmarty->fetch(IA_PLUGINS . 'comments/templates/front/comment.tpl');

				$messages[] = iaLanguage::get('comment_added');
			}
			else
			{
				$messages[] = iaLanguage::get('comment_added') . ' ' . iaLanguage::get('comment_waits_approve');
			}

			$iaDb->resetTable();
		}

	}

	$output['error'] = $error;
	$output['msg'] = $messages;

	$iaView->assign($output);
}